/*
** NK Common Header - basic definition shared by multiple modules
*/

/***********************************************************************
** Standard header preamble.  Ensure singular inclusion, setup for
** function prototypes and c++ inclusion
*/

#ifndef NK_COMMON_H

#define NK_COMMON_H 1

#if defined(__STDC__) || defined(__cplusplus)
#  define __ANSI_PROTO(x)       x
#else
#  define __ANSI_PROTO(x)       ()
#endif

#ifdef __cplusplus
extern "C" {
#endif

#include "config.h"


/***********************************************************************
** Macro Definitions
*/

/*! cpp_macro
!descr API Routine Error Return Values
!macro NK_OK Operation completed successfully
!macro NK_ERR_FILE An file oriented operation, such as opening a file, failed
!macro NK_ERR_ENTRY An entry, such as a formatted data string, was not valid
!macro NK_ERR_RANGE A value specified is outside of the valid range of values
!macro NK_ERR_VALUE A value specified is not valid
!macro NK_ERR_NO_MEMORY An attempt to allocate memory has failed
!*/

#define	NK_OK			0
#define NK_ERR_FILE		-1
#define NK_ERR_ENTRY		-1
#define NK_ERR_RANGE		-2
#define NK_ERR_VALUE		-3
#define NK_ERR_NO_MEMORY	-3


/*!
!cpp_macro Limit and Length Specifications
!macro NK_MAX_ERR_LEN The maximum length of an error message
!macro NK_MAX_PATH_LEN The maximum length of a file's complete path name
!macro NK_MAX_HOSTNAME_LEN The maximum length of an element hostname
!macro NK_MAX_EVENT_MSG_LEN The maximum length of an event notification message
!macro
!*/

#define NK_MAX_ERR_LEN		255
#define	NK_MAX_PATH_LEN		255
#define	NK_MAX_HOSTNAME_LEN	80
#define NK_MAX_EVENT_MSG_LEN	160
#define NK_MAX_SNMP_OID_LEN	40
#define NK_MAX_SNMP_VAR_LEN	320
#define NK_MAX_SNMP_TEXT_LEN	1024
#define NK_MAX_NAME_LEN		25
#define	NK_MAX_VAR_NAME_LEN	24
#define NK_MAX_SCRIPT_LEN	2048
#define	NK_MAX_DESCR_NAME_LEN	80


#define	NK_INST_DIR		"/usr/local/nk"



#define	NK_VERSION_MAJ		0
#define NK_VERSION_MIN		1
#define NK_VERSION_EXTRA	"alpha"

#define skip_blanks(ptr) while(*ptr==' '||*ptr=='\t'){ptr++;}
#define skip_nonblanks(ptr) while(*ptr!=' '&&*ptr!='\t'){ptr++;}
#define is_white(ptr) (ptr==' '||ptr=='\t'||ptr=='\n'||ptr==0)


/***********************************************************************
** Standard header file footer.  
*/

#ifdef __cplusplus
	}
#endif /* __cplusplus */
#endif /* file inclusion */

